@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -13,9 +12,7 @@ in a specified Python module.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -26,8 +23,6 @@ log = logging.getLogger(__name__)
 import codecs
 import os
 
-# External imports
-
 # Bokeh imports
 from ...util.callback_manager import _check_callback
 from .code_runner import CodeRunner
@@ -64,16 +59,17 @@ class ServerLifecycleHandler(LifecycleHandler):
                 ``sys.argv`` when the callback code is executed. (default: [])
 
         '''
-        super(ServerLifecycleHandler, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         if 'filename' not in kwargs:
             raise ValueError('Must pass a filename to ServerLifecycleHandler')
         filename = kwargs['filename']
         argv = kwargs.get('argv', [])
+        package = kwargs.get('package', False)
 
         source = codecs.open(filename, 'r', 'UTF-8').read()
 
-        self._runner = CodeRunner(source, filename, argv)
+        self._runner = CodeRunner(source, filename, argv, package=package)
 
         if not self._runner.failed:
             # unlike ScriptHandler, we only load the module one time
