@@ -22,6 +22,7 @@ log = logging.getLogger(__name__)
 from inspect import isclass
 from json import loads
 from operator import itemgetter
+from typing import Type, Union
 
 # Bokeh imports
 from .core.has_props import HasProps, abstract
@@ -73,7 +74,7 @@ def collect_filtered_models(discard, *input_values):
 
     '''
 
-    ids = set([])
+    ids = set()
     collected = []
     queued = []
 
@@ -364,19 +365,21 @@ class Model(HasProps, PropertyCallbackManager, EventCallbackManager):
 
     # Public methods ----------------------------------------------------------
 
-    def js_on_event(self, event, *callbacks):
-
-        if not isinstance(event, str) and issubclass(event, Event):
+    def js_on_event(self, event: Union[str, Type[Event]], *callbacks) -> None:
+        if isinstance(event, str):
+            pass
+        elif isinstance(event, type) and issubclass(event, Event):
             event = event.event_name
+        else:
+            raise ValueError(f"expected string event name or event class, got {event}")
 
-        if event not in self.js_event_callbacks:
-            self.js_event_callbacks[event] = []
+        all_callbacks = list(self.js_event_callbacks.get(event, []))
 
         for callback in callbacks:
-            if callback in self.js_event_callbacks[event]:
-                continue
-            self.js_event_callbacks[event].append(callback)
+            if callback not in all_callbacks:
+                all_callbacks.append(callback)
 
+        self.js_event_callbacks[event] = all_callbacks
 
     def js_link(self, attr, other, other_attr, attr_selector=None):
         ''' Link two Bokeh model properties using JavaScript.
@@ -678,6 +681,8 @@ class Model(HasProps, PropertyCallbackManager, EventCallbackManager):
         Model.model_class_reverse_map = {
             k: v for k, v in Model.model_class_reverse_map.items()
             if getattr(v, "__implementation__", None) is None
+                and getattr(v, "__javascript__", None) is None
+                and getattr(v, "__css__", None) is None
         }
 
     def _detach_document(self):
